@@ -24,6 +24,9 @@ from logging import debug, info, warning, error
 import encodings
 utf8decode = lambda s: encodings.codecs.utf_8_decode(s)[0]
 
+from urwid.util import is_mouse_press #XXX: is_mouse_press is not include in urwid in 1.0.0
+
+
 class Password(urwid.Edit):
     """Edit box which doesn't show what is entered (show '*' or other char instead)"""
 
@@ -231,7 +234,7 @@ class SelectableText(urwid.WidgetWrap):
             return key
 
     def mouse_event(self, size, event, button, x, y, focus):
-        if urwid.is_mouse_press(event) and button == 1:
+        if is_mouse_press(event) and button == 1:
             self.setState(not self.__selected)
             return True
         
@@ -865,7 +868,7 @@ class ColumnsRoller(urwid.FlowWidget):
     def mouse_event(self, size, event, button, x, y, focus):
         (maxcol,)=size
 
-        if urwid.is_mouse_press(event) and button == 1:
+        if is_mouse_press(event) and button == 1:
             _prev,_next,start_wid,end_wid,cols_left = self.__calculate_limits(size)
             if x==0 and _prev:
                 self.keypress(size,'left')
